==> trade-center-api-2.4.23-20220520.021458-2-sources.jar: cn/com/duiba/order/center/api/remoteservice/RemoteOrdersTextChangeService.java <==
package cn.com.duiba.order.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.order.center.api.dto.OrdersDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.Date;
import java.util.Map;

/**
 * Created by yansen on 16/9/27.
 */
@AdvancedFeignClient
public interface RemoteOrdersTextChangeService {
    /**
     * 更新订单错误信息，状态，错误类型
     * @param orderId
     * @param consumerId
     * @param failType
     * @param errorMessage
     * @param error4Consumer
     * @param error4Develper
     * @param error4Admin
     * @return
     */
    public DubboResult<Integer> updateErrorMessageAndFailType(Long orderId, Long consumerId, Integer failType, String errorMessage,
                                                             String error4Consumer, String error4Develper, String error4Admin);

    /**
     * 更新最后发送时间
     * @param orderId
     * @param consumerId
     * @param lastSendTime
     * @return
     */
    public DubboResult<Integer> updateLastSendTime(Long orderId, Long consumerId, Date lastSendTime);

    /**
     * 更新开发者订单号
     * @param orderId
     * @param consumerId
     * @param developBizId
     * @return
     */
    public DubboResult<Integer> updateDevelopBizId(Long orderId,Long consumerId, String developBizId);

    /**
     * 更新上游订单
     * @param orderId
     * @param consumerId
     * @param supplierOrderId
     * @return
     */
    public DubboResult<Integer> updateSupplierOrderId(Long orderId,  Long consumerId, Long supplierOrderId);

    /**
     *
     * @param orderId
     * @param consumerId
     * @return
     */
    DubboResult<Integer> releaseCouponByOrderId(Long orderId, Long consumerId);

    /**
     * 下订单,更新优惠券ID, 兼容老版本
     * @deprecated  请使用 RemoteOrderItemService.updateCouponId
     * @param orderId
     * @param consumerId
     * @param couponId
     * @return
     */
    @Deprecated
    DubboResult<Integer> updateCouponId(Long orderId, Long consumerId, Long couponId);

    /**
     * @param orderId
     * @param consumerId
     * @param error4admin
     * @param error4developer
     * @param error4consumer
     * @return
     */
    DubboResult<Integer> updateErrorInfo(Long orderId, Long consumerId, String error4admin, String error4developer, String error4consumer);

    /**
     * 不管你传了啥参数，该接口只会保存 isRestoreBudget 参数  Surprise !!
     * @param orderId
     * @param consumerId
     * @param key
     * @param value
     * @return
     * 
     * @see #addExtraInfoNew(Long, Long, String, Object)
     */
    @Deprecated
    DubboResult<Integer> addExtraInfo(Long orderId, Long consumerId, String key, String value);

    /**
     * 在订单 extra_info 字段中增加参数
     * @param orderId
     * @param consumerId
     * @param key
     * @param value
     * @return
     */
    Integer addExtraInfoNew(Long orderId, Long consumerId, String key, Object value);

    /**
     * 批量在extra_info 增加参数
     * @param orderId
     * @param consumerId
     * @param params
     * @return
     */
    Integer addExtraInfoByParams(Long orderId, Long consumerId, Map<String,Object> params);

    Boolean updateOrderPayPrice(OrdersDto ordersDto);

    /**
     * 更新bizParams 目前用于更新实物的收获地址
     * @param ordersDto
     * @return
     */
    Boolean updateBizParams(OrdersDto ordersDto);
}

==> trade-center-api-2.4.32.1-20220707.043749-1-sources.jar: cn/com/duiba/order/center/api/remoteservice/RemoteOrdersTextChangeService.java <==
package cn.com.duiba.order.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.order.center.api.dto.OrdersDto;
import cn.com.duiba.wolf.dubbo.DubboResult;
import com.alibaba.fastjson.JSONObject;

import java.util.Date;
import java.util.Map;

/**
 * Created by yansen on 16/9/27.
 */
@AdvancedFeignClient
public interface RemoteOrdersTextChangeService {
    /**
     * 更新订单错误信息，状态，错误类型
     * @param orderId
     * @param consumerId
     * @param failType
     * @param errorMessage
     * @param error4Consumer
     * @param error4Develper
     * @param error4Admin
     * @return
     */
    public DubboResult<Integer> updateErrorMessageAndFailType(Long orderId, Long consumerId, Integer failType, String errorMessage,
                                                             String error4Consumer, String error4Develper, String error4Admin);

    /**
     * 更新最后发送时间
     * @param orderId
     * @param consumerId
     * @param lastSendTime
     * @return
     */
    public DubboResult<Integer> updateLastSendTime(Long orderId, Long consumerId, Date lastSendTime);

    /**
     * 更新开发者订单号
     * @param orderId
     * @param consumerId
     * @param developBizId
     * @return
     */
    public DubboResult<Integer> updateDevelopBizId(Long orderId,Long consumerId, String developBizId);

    /**
     * 更新上游订单
     * @param orderId
     * @param consumerId
     * @param supplierOrderId
     * @return
     */
    public DubboResult<Integer> updateSupplierOrderId(Long orderId,  Long consumerId, Long supplierOrderId);

    /**
     *
     * @param orderId
     * @param consumerId
     * @return
     */
    DubboResult<Integer> releaseCouponByOrderId(Long orderId, Long consumerId);

    /**
     * 下订单,更新优惠券ID, 兼容老版本
     * @deprecated  请使用 RemoteOrderItemService.updateCouponId
     * @param orderId
     * @param consumerId
     * @param couponId
     * @return
     */
    @Deprecated
    DubboResult<Integer> updateCouponId(Long orderId, Long consumerId, Long couponId);

    /**
     * @param orderId
     * @param consumerId
     * @param error4admin
     * @param error4developer
     * @param error4consumer
     * @return
     */
    DubboResult<Integer> updateErrorInfo(Long orderId, Long consumerId, String error4admin, String error4developer, String error4consumer);

    /**
     * 不管你传了啥参数，该接口只会保存 isRestoreBudget 参数  Surprise !!
     * @param orderId
     * @param consumerId
     * @param key
     * @param value
     * @return
     * 
     * @see #addExtraInfoNew(Long, Long, String, Object)
     */
    @Deprecated
    DubboResult<Integer> addExtraInfo(Long orderId, Long consumerId, String key, String value);

    /**
     * 在订单 extra_info 字段中增加参数
     * @param orderId
     * @param consumerId
     * @param key
     * @param value
     * @return
     */
    Integer addExtraInfoNew(Long orderId, Long consumerId, String key, Object value);

    /**
     * 批量在extra_info 增加参数
     * @param orderId
     * @param consumerId
     * @param params
     * @return
     */
    Integer addExtraInfoByParams(Long orderId, Long consumerId, Map<String,Object> params);

    Integer batchAddExtraInfo(Long orderId, Long consumerId, JSONObject json);

    Boolean updateOrderPayPrice(OrdersDto ordersDto);

    /**
     * 更新bizParams 目前用于更新实物的收获地址
     * @param ordersDto
     * @return
     */
    Boolean updateBizParams(OrdersDto ordersDto);
}
